import { Component, h, Prop } from '@stencil/core';
import { ALLOWED_ANIMATIONS } from './skeleton.constants';
export class Skeleton {
  constructor() {
    /**
     * Number of rows of current skeleton type
     *
     * @memberof Skeleton
     */
    this.count = 1;
    /**
     * Variant of the skeleton - circle or row
     *
     * @type {('circle' | '')}
     * @memberof Skeleton
     */
    this.variant = 'text';
    /**
     * Width of the skeleton ex. 100px, 100%, auto etc.
     *
     *
     * @type {string}
     * @memberof Skeleton
     */
    this.width = null;
    /**
     * Height of the skeleton ex. 100px, 100%, auto etc.
     *
     * @type {string}
     * @memberof Skeleton
     */
    this.height = null;
    /**
     * MarginBottom of the skeleton ex. 10px, 0 etc.
     *
     * @type {string}
     * @memberof Skeleton
     */
    this.marginBottom = null;
    /**
     * Animation type
     *
     * @type {('progress' | 'progress-dark' | 'pulse' | 'false')}
     * @memberof Skeleton
     */
    this.animation = 'progress';
    /**
     * Custom css styles (background/margins/width/height etc.)
     *
     * @type {({[k: string]: string} | string)}
     * @memberof Skeleton
     */
    this.customStyles = {};
    /**
     * Whether to show warnings for the wrong animation type/custom styles
     *
     * @memberof Skeleton
     */
    this.showWarnings = true;
    this.items = [];
  }
  componentWillLoad() {
    this.init();
  }
  componentWillUpdate() {
    this.init();
  }
  init() {
    this.items.length = this.count;
    this.items.fill(1);
    if (!ALLOWED_ANIMATIONS.includes(this.animation)) {
      if (this.showWarnings) {
        console.warn(`\`Skeleton\` need to receive 'animation' as: ${ALLOWED_ANIMATIONS.join(', ')}. Forcing default to "progress".`);
      }
      this.animation = 'progress';
    }
    if (this.customStyles && typeof this.customStyles === 'string') {
      try {
        this.customStyles = JSON.parse(this.customStyles);
      }
      catch (error) {
        if (this.showWarnings) {
          console.warn(`can't parse styles`, this.customStyles);
        }
      }
    }
  }
  get style() {
    let dimenssionsStyles = {
      width: null,
      height: null,
      marginBottom: null
    };
    if (this.width) {
      dimenssionsStyles.width = this.width;
    }
    if (this.height) {
      dimenssionsStyles.height = this.height;
    }
    if (this.marginBottom) {
      dimenssionsStyles.marginBottom = this.marginBottom;
    }
    const styles = typeof this.customStyles === 'object' ? this.customStyles : {};
    return Object.assign(Object.assign({}, dimenssionsStyles), styles);
  }
  render() {
    return this.items.map((_, index) => {
      return (h("span", { key: index, class: {
          circle: this.variant === 'circle',
          rect: this.variant === 'rect',
          progress: this.animation === 'progress',
          'progress-dark': this.animation === 'progress-dark',
          pulse: this.animation === 'pulse',
          skeleton: true
        }, "aria-busy": "true", "aria-valuemin": "0", "aria-valuemax": "100", "aria-valuetext": "Loading...", role: "progressbar", tabindex: "0", style: this.style }));
    });
  }
  static get is() { return "nb-skeleton"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["skeleton.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["skeleton.css"]
  }; }
  static get properties() { return {
    "count": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "memberof",
            "text": "Skeleton"
          }],
        "text": "Number of rows of current skeleton type"
      },
      "attribute": "count",
      "reflect": false,
      "defaultValue": "1"
    },
    "variant": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'circle' | 'rect' | 'text'",
        "resolved": "\"circle\" | \"rect\" | \"text\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "type",
            "text": "{('circle' | '')}"
          }, {
            "name": "memberof",
            "text": "Skeleton"
          }],
        "text": "Variant of the skeleton - circle or row"
      },
      "attribute": "variant",
      "reflect": false,
      "defaultValue": "'text'"
    },
    "width": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "type",
            "text": "{string}"
          }, {
            "name": "memberof",
            "text": "Skeleton"
          }],
        "text": "Width of the skeleton ex. 100px, 100%, auto etc."
      },
      "attribute": "width",
      "reflect": false,
      "defaultValue": "null"
    },
    "height": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "type",
            "text": "{string}"
          }, {
            "name": "memberof",
            "text": "Skeleton"
          }],
        "text": "Height of the skeleton ex. 100px, 100%, auto etc."
      },
      "attribute": "height",
      "reflect": false,
      "defaultValue": "null"
    },
    "marginBottom": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "type",
            "text": "{string}"
          }, {
            "name": "memberof",
            "text": "Skeleton"
          }],
        "text": "MarginBottom of the skeleton ex. 10px, 0 etc."
      },
      "attribute": "margin-bottom",
      "reflect": false,
      "defaultValue": "null"
    },
    "animation": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'progress' | 'progress-dark' | 'pulse' | 'false'",
        "resolved": "\"false\" | \"progress\" | \"progress-dark\" | \"pulse\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "type",
            "text": "{('progress' | 'progress-dark' | 'pulse' | 'false')}"
          }, {
            "name": "memberof",
            "text": "Skeleton"
          }],
        "text": "Animation type"
      },
      "attribute": "animation",
      "reflect": false,
      "defaultValue": "'progress'"
    },
    "customStyles": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "{ [key: string]: string } | string",
        "resolved": "string | { [key: string]: string; }",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "type",
            "text": "{({[k: string]: string} | string)}"
          }, {
            "name": "memberof",
            "text": "Skeleton"
          }],
        "text": "Custom css styles (background/margins/width/height etc.)"
      },
      "attribute": "custom-styles",
      "reflect": false,
      "defaultValue": "{}"
    },
    "showWarnings": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "memberof",
            "text": "Skeleton"
          }],
        "text": "Whether to show warnings for the wrong animation type/custom styles"
      },
      "attribute": "show-warnings",
      "reflect": false,
      "defaultValue": "true"
    }
  }; }
}
